import { ElementRef } from '@angular/core';
import { ControlValueAccessor } from '@angular/forms';
import * as i0 from "@angular/core";
export declare class SpSelectComponent implements ControlValueAccessor {
    private readonly hostElementRef;
    private spSelect;
    private optionsPanel;
    /**
     * List of values that can then be selected as an option.<br>
     * An option can either be a primitive or an object, <b>but all options must be of the same type</b>.
     * @param options List of selectable values
     */
    set options(options: any[]);
    /**
     * Indicates if a button is displayed to clear the current selection.
     * @param clearable Show or hide the clear button
     */
    set clearable(clearable: boolean);
    /**
     * <b>Only relevant if the options are objects!</b><br><br>
     * Name of the property that should be used to display the option and the selected value.
     * @param property Property name
     */
    set labelProperty(property: string);
    /**
     * <b>Only relevant if the options are objects!</b><br><br>
     * Name of the property that should be used to identify an option.<br>
     * If no {@link labelProperty} is set, this property is used to display the option and the selected value instead.
     * @param property Property name
     */
    set keyProperty(property: string);
    /**
     * Text that should be displayed if no value is selected.
     * @param placeholder Placeholder text
     */
    set placeholder(placeholder: string);
    /**
     * Sets the disabled state of this component.
     * @param disabled Disabled state
     */
    set disabled(disabled: boolean);
    readonly options$: import("@angular/core").WritableSignal<any[]>;
    readonly clearable$: import("@angular/core").WritableSignal<boolean>;
    readonly labelProperty$: import("@angular/core").WritableSignal<string | null>;
    readonly keyProperty$: import("@angular/core").WritableSignal<string | null>;
    readonly placeholder$: import("@angular/core").WritableSignal<string>;
    readonly disabled$: import("@angular/core").WritableSignal<boolean>;
    readonly label$: import("@angular/core").Signal<string>;
    readonly tabindex$: import("@angular/core").Signal<number>;
    readonly optionRenderLabel$: import("@angular/core").Signal<boolean>;
    readonly optionRenderKey$: import("@angular/core").Signal<boolean>;
    readonly showOptionPanel$: import("@angular/core").WritableSignal<boolean>;
    readonly optionPanelStyle$: import("@angular/core").WritableSignal<any>;
    readonly controlValue$: import("@angular/core").WritableSignal<any>;
    private onChangeFn;
    private onTouchedFn;
    constructor(hostElementRef: ElementRef);
    private canSetValue;
    private getOptionByValue;
    private recalculateOptionsPanelStyle;
    registerOnChange(onChangeFn: any): void;
    registerOnTouched(onTouchedFn: any): void;
    setDisabledState(isDisabled: boolean): void;
    writeValue(value: any | null): void;
    toggleOptionPanel(): void;
    selectOption(option: any): void;
    clearValue(mouseEvent?: MouseEvent): void;
    isOptionSelected(option: any): boolean;
    focus(): void;
    blur(event: FocusEvent): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<SpSelectComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<SpSelectComponent, "sp-select", never, { "options": { "alias": "options"; "required": false; }; "clearable": { "alias": "clearable"; "required": false; }; "labelProperty": { "alias": "labelProperty"; "required": false; }; "keyProperty": { "alias": "keyProperty"; "required": false; }; "placeholder": { "alias": "placeholder"; "required": false; }; "disabled": { "alias": "disabled"; "required": false; }; }, {}, never, never, false, never>;
}
